@@ -18,11 +18,13 @@ while ( defined( my $file = $files->() ) ) {
     next if ( $file !~ /\.(p[ml]|t)$/ );            # only .pm .pl .t
     next if ( $file =~ /Schema\.pm$/ );             # skip this file
     next if ( $file =~ /(\/|\\)Schema(\/|\\)/ );    # skip Schema dir and Schema.pm
+    next if ( $file =~ /Version\.pm/ );             # skip Foorum/Version.pm
 
     print "$file\n";
 
     my @violations = $critic->critique($file);
-    $file =~ s/^((.*?)trunk(\\|\/))//isg;
+    $file =~ s/\\/\//isg;                           # for Win32
+    $file =~ s/^$path//isg;
     unless ( scalar @violations ) {
         print $fh "$file source OK\n";
     } else {
